aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/pkg/pkg.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/pkg/pkg.go')
-rw-r--r--internal/pkg/pkg.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/pkg/pkg.go b/internal/pkg/pkg.go
index 4ab3125a..b50dc48e 100644
--- a/internal/pkg/pkg.go
+++ b/internal/pkg/pkg.go
@@ -141,8 +141,8 @@ func Ident(a Artifact) ID {
type Kind uint64
const (
- // KindHTTP is the kind of [Artifact] returned by [NewHTTP].
- KindHTTP Kind = iota
+ // KindHTTPGet is the kind of [Artifact] returned by [NewHTTPGet].
+ KindHTTPGet Kind = iota
// KindTar is the kind of artifact returned by [NewTar].
KindTar
)